Learn R Programming

aurin (version 0.6.0)

aur_browse: Browse AURIN data catalogue.

Description

A convenience function that opens up AURIN data catelogue in your default web browser. Use the data catalogue to select spatial datasets available on AURIN. Any datasets with 'AURIN Open API ID' field can be downloaded into your current R session with aur_get().

Usage

aur_browse()

Arguments

Examples

Run this code
# NOT RUN {
aur_browse()
# }

Run the code above in your browser using DataLab