Learn R Programming

aurin (version 0.6.0)

aurin-package: aurin: Access Datasets from the 'AURIN' API

Description

'AURIN' <https://aurin.org.au/resources/aurin-apis/> is "Australia's single largest resource for accessing clean, integrated, spatially enabled and research-ready data on issues surrounding health and wellbeing, socio-economic metrics, transportation, and land-use.". This package provides functions to download and search datasets from the AURIN API (it's free to use!).

Arguments

See Also

Useful links: